@@ -11,8 +11,15 @@ configured by the user. Any logged messages before
 Special care is taken by both methods to ensure all errors are logged
 and properly flushed before program exit.
 
+The `logging` module is useful for recording messages about about what
+Certbot is doing under the hood, but do not necessarily need to be shown
+to the user on the terminal. The default verbosity is INFO.
+
+The preferred method to display important information to the user is to
+use `certbot.display.util` and `certbot.display.ops`.
+
 """
-from __future__ import print_function
+
 
 import functools
 import logging
@@ -102,11 +109,12 @@ def post_arg_parse_setup(config):
 
     root_logger.addHandler(file_handler)
     root_logger.removeHandler(memory_handler)
-    temp_handler = memory_handler.target  # pylint: disable=no-member
+    temp_handler = getattr(memory_handler, 'target', None)
     memory_handler.setTarget(file_handler)  # pylint: disable=no-member
     memory_handler.flush(force=True)  # pylint: disable=unexpected-keyword-arg
     memory_handler.close()
-    temp_handler.close()
+    if temp_handler:
+        temp_handler.close()
 
     if config.quiet:
         level = constants.QUIET_LOGGING_LEVEL
@@ -198,7 +206,7 @@ class MemoryHandler(logging.handlers.MemoryHandler):
         """Close the memory handler, but don't set the target to None."""
         # This allows the logging module which may only have a weak
         # reference to the target handler to properly flush and close it.
-        target = self.target
+        target = getattr(self, 'target')
         super(MemoryHandler, self).close()
         self.target = target
 
